package dynaaminenDouble;


/**
 * Esimerkki dynaamisesta taulukosta 
 * @author vesal
 * @version 27.2.2024
 * @example
 * <pre name="test">
 *  #THROWS Taulukko.TaulukkoTaysiException
 *  Taulukko luvut = new Taulukko();
 *  luvut.add(0); luvut.add(2); luvut.add(99);
 *  luvut.toString() === "0,2,99";
 *  luvut.set(1,4); luvut.toString() === "0,4,99";
 *  int luku = luvut.get(2);
 *  luku === 99;
 *  luvut.get(2) === 99;
 *  luvut.set(21, 4); #THROWS IndexOutOfBoundsException
 *  luvut.add(0); luvut.add(0); //taulukko täyteen
 *  luvut.add(0);  #THROWS Taulukko.TaulukkoTaysiException
 * </pre>
 */
public class Taulukko {
    
    /** Luokka täyden taulukon poikkeusta varten  */
    public static class TaulukkoTaysiException extends Exception {
        private static final long serialVersionUID = 1L;
        /**
         * @param viesti viesti joka tulee poikkeuksesta
         */
        public TaulukkoTaysiException(String viesti) {
            super(viesti);
        }
    }

    
    
    private double[] alkiot;
    private int lkm;
    
    /**
     * Luodaan 5 kokoinen taulukko
     */
    public Taulukko() {
        alkiot = new double[5];
        lkm = 0;
    }
    
    
    /**
     * Lisätään tietorakenteeseen luku
     * @param luku lisättävä luku
     * @throws TaulukkoTaysiException jos ei mahu
     */
    public void add(double luku) throws TaulukkoTaysiException {
        if (lkm >= alkiot.length) throw new TaulukkoTaysiException("Liikaa alkioita. Ei mahu " + luku);
        alkiot[lkm] = luku;
        lkm++;
    }
    

    /**
     * Laitetaan paikkaan i arvo
     * @param i mihin
     * @param arvo uusi arvo
     * @throws IndexOutOfBoundsException jos väärä paikka
     */
    public void set(int i, double arvo) throws IndexOutOfBoundsException {
        if ((i < 0) || (lkm <= i)) throw new IndexOutOfBoundsException("set i = " + i + ": " + arvo);
        alkiot[i] = arvo;
    }


    /**
     * Annetaan paikassa i oleva arvo
     * @param i mistä
     * @return paikassa i oleva arvo
     */
    public double get(int i) {
        if ((i < 0) || (lkm <= i)) throw new IndexOutOfBoundsException("get i = " + i);
        return alkiot[i];
    }
    
    
    @Override
    public String toString() {
        StringBuilder s = new StringBuilder("");
        String erotin = "";
        for (int i = 0; i < lkm; i++) {  // "0,2,99"
            s.append(erotin);
            s.append(alkiot[i]);
            erotin = ",";
        }
        return s.toString();
    }
    
    /**
     * Kokeillaan taulukkoa
     * @param args ei käytössä
     */
    public static void main(String[] args)  {
        Taulukko luvut = new Taulukko();
        try {
            luvut.add(0);
            luvut.add(2.5); 
            luvut.add(99);
            System.out.println(luvut.toString());
            luvut.set(1,4);
            System.out.println(luvut.toString());
            
            double luku = luvut.get(2);
            System.out.println(luku);
            // luvut.set(21, 4); 
            
            luvut.add(199);
            luvut.add(299);
            luvut.add(399);
            luvut.add(499);
            luvut.add(599);
            luvut.add(699);
            luvut.add(799);
            luvut.add(899);
        } catch (IndexOutOfBoundsException e) {
            System.err.println(e.getMessage());
        } catch (TaulukkoTaysiException e) {
            System.err.println(e.getMessage());
        } 
    }


}
