package funktio;

/**
 * Ohjelmalla integroidaan numeerisesti 
 * @author Vesa Lappalainen
 * @version 1.0 
 */
// @SuppressWarnings("javadoc")
public class Integroi2 {
    
    /**
     * Rajapinta kaikille funktiolle R->R
     */
    public interface FunktioRR {
        /**
         * @param x piste jossa lasketaan
         * @return funktion arvo pisteessä
         */
        public double f(double x);
    }

    
    /**
     * Luokka sini-funktiolla
     */
    public static class SinFun implements FunktioRR {
        @Override
        public double f(double x) {
            return Math.sin(x);
        }
    }
    

    /**
     * Integroidaan sin(x) välillä x1-x2
     * @param funk funktio jota integroidaan
     * @param x1 alkuarvo
     * @param x2 loppuarvo
     * @param tiheys monellako askeleella
     * @return likiarvo integraalille
     */ 
    public static double integroi(FunktioRR funk, double x1, double x2, int tiheys) {
        double summa = 0;
        double dx = (x2-x1)/tiheys;
        for (double x = x1 + dx/2; x < x2; x += dx ) 
            summa += funk.f(x) * dx;
        return summa;
    }
  
    
    /**
     * Luokka 2-asteen polynomille
     */
    public static class P2 implements FunktioRR {
        private double a;
        private double b;
        private double c;

        /**
         * Alustetaan polynomiksi x^2 
         */
        public P2() {
            this.a = 1;
            this.b = 0;
            this.c = 0;
        }

        
        /**
         * Alustetaan polynomi kertoimilla
         * @param a x^2 kerroin
         * @param b x:n kerroin
         * @param c vakiotermi
         */
        public P2(double a, double b, double c) {
            this.a = a;
            this.b = b;
            this.c = c;
        }
        
        
        
        @Override
        public double f(double x) {
            return a*x*x + b*x + c;
        }
    }

    
    /**
     * @param args ei käytössä
     */
    public static void main(String[] args) {
        FunktioRR sin = new SinFun();
        double ala = integroi(sin, 0,Math.PI,1000);
        System.out.printf("%17.15f%n",ala);
        FunktioRR p2 = new P2(1, 2, -3);
        
        ala = integroi(p2, 0, 1,1000);
        System.out.printf("%17.15f%n",ala);
        
        FunktioRR exp = new FunktioRR() {
            @Override
            public double f(double x) { return Math.exp(x); }
        };

        ala = integroi(exp, 0, 1,1000);
        System.out.printf("%17.15f%n",ala);
        
        FunktioRR exp2 = x -> Math.exp(x); 
        ala = integroi(exp2, 0, 1,1000);
        System.out.printf("%17.15f%n",ala);
        
        ala = integroi(new FunktioRR() {
            @Override
            public double f(double x) { return Math.exp(x); }
        }, 0, 1,1000);

        ala = integroi(x -> Math.exp(x), 0, 1,1000);
        System.out.printf("%17.15f%n",ala);
    }
}
