package testaaminen;

/**
 * Testiohjelma jonosta poistolle
 * @author Vesa Lappalainen
 * @version 1.0, 26.01.2002
 * @version 1.1, 27.01.2007
 */
public class Poista {
    /**
     * Poistaa merkkijonosta jono kaikki jonon mita esiintymät.
     * <pre>
     *  jono   oistettava       tulos
     * Catcat      at      =>    Cc
     * Paatti      at      =>    Pi
     * Puatit      at      =>    Puit
     * </pre>
     * @param jono merkkijono josta poistetaan
     * @param poistettava jono, jonka esiintymää ei saa olla tuloksessa
     * @return jono jossa ei ole yhtään poistettava-jonon esiintymää
     * @since 1.4
     * @example
     * <pre name="test">
     *   poista("Catcat"   ,"at")  ===  "Cc";
     *   poista("Paatti"   ,"at")  ===  "Pi";
     *   poista("Puatit"   ,"at")  ===  "Puit";
     *   poista("Abba"     ,"bb")  ===  "Aa";               
     *   poista("Abbababba","ba")  ===  "Abb";
     *   poista("AbbabaaB" ,"ba")  ===  "AB";
     *   poista("Abba"     ,"Ab")  ===  "ba";                
     *   poista("Abba"     ,""  )  ===  "Abba";
     *   poista(""         ,"Aa")  ===  "";
     *   poista(""         ,""  )  ===  "";
     *   poista(null       ,""  )  ===  "";
     *   poista(null       ,"k"  ) ===  "";  // # THROWS NullPointerException
     *   poista("Kissa"    ,null)  ===  "Kissa";
     * </pre>
     * 
     * 
     */
    public static String poista(String jono, String poistettava) {
        return demo.d3.Poista.poista(jono,poistettava);
    }


    /**
     * Testi poista-aliohjelmalle
     * @param jono josta poistetaan
     * @param mita mitä jonoa poistetaan
     * @param odotettuTulos jono joka pitäisi olla poiston jälkeen
     * @return 0 jos ok, 1  muuten
     */
    private static int poistatesti(String jono, String mita, String odotettuTulos) {
        String vaihdettu = poista(jono, mita);
        if (vaihdettu.equals(odotettuTulos)) return 0;
        System.out.println(jono + " => " + vaihdettu + " piti tulla "
                + odotettuTulos);
        return 1;
    }


    /**
     * Testataan poista-aliohjelmaa
     * @param args ei käytössä
     */
    public static void main(String[] args) {
        int v = 0;
        v += poistatesti("Catcat", "at", "Cc");
        v += poistatesti("Paatti", "at", "Pi");
        v += poistatesti("Puatit", "at", "Puit");
        v += poistatesti("Abba", "bb", "Aa");  
        v += poistatesti("Abbababba", "ba", "Abb");
        v += poistatesti("AbbabaaB", "ba", "AB");
        v += poistatesti("Abba", "Aa", "Abba");
        v += poistatesti("Abba", "", "Abba");
        v += poistatesti("", "Aa", "");
        v += poistatesti("", "", "");
        System.out.println("Virheitä: " + v);
    }
}
